<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// R
	'revisions_description' => 'De revisies van de editoriale objecten volgen', # Robert & Van Dale: revisie de (v.) 1 herziening - révision (v.) -  context: revisie van de drukproef, révision, correction de l'épreuve 2 periodieke controle - révision (v.) vérification (v.)  Vu la similarité avec le fr je opense que c'est le meilleur terme (Wijzigingen = changements, c'est pas pareil)
	'revisions_slogan' => 'Revisies laat je toe de  veranderingen van de editorialen objecten zien en volgen.',
];
